/* Copyright (C) 2013 by Bundesanstalt für Gewässerkunde
 * Software engineering by Intevation GmbH
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */

package org.dive4elements.river.exports.process;

import org.dive4elements.artifactdatabase.state.ArtifactAndFacet;
import org.dive4elements.artifacts.CallContext;
import org.dive4elements.river.artifacts.D4EArtifact;
import org.dive4elements.river.artifacts.access.RiverAccess;
import org.dive4elements.river.artifacts.context.RiverContext;
import org.dive4elements.river.artifacts.model.FacetTypes;
import org.dive4elements.river.artifacts.model.ZoomScale;
import org.dive4elements.river.artifacts.resources.Resources;
import org.dive4elements.river.exports.DiagramGenerator;
import org.dive4elements.river.themes.ThemeDocument;

public class WDiffProcessor extends WOutProcessor {

    public final static String I18N_WDIFF_YAXIS_LABEL =
        "chart.w_differences.yaxis.label";

    public final static String I18N_WDIFF_YAXIS_LABEL_DEFAULT = "m";

    public static final String I18N_SUBTITLE_RADIUS =
        "chart.subtitle.radius";

    @Override
    public void doOut(
            DiagramGenerator generator,
            ArtifactAndFacet bundle,
            ThemeDocument    theme,
            boolean          visible) {
        CallContext context = generator.getCallContext();
        Double start = (Double)context.getContextValue("startkm");
        Double end = (Double)context.getContextValue("endkm");
        if (start != null && end != null) {
            D4EArtifact artifact = (D4EArtifact)bundle.getArtifact();
            RiverContext fc = (RiverContext)context.globalContext();
            // Adaptive smoothing, based on zoom factor/diagram extents.
            ZoomScale scales = (ZoomScale)fc.get("zoomscale");
            RiverAccess access = new RiverAccess((D4EArtifact)artifact);
            String river = access.getRiverName();

            double radius = scales.getRadius(river, start, end);
            generator.addSubtitle(Resources.getMsg(
                context.getMeta(),
                I18N_SUBTITLE_RADIUS,
                new Object[] { radius }));
        }
        super.doOut(generator, bundle, theme, visible);
    }
    @Override
    public boolean canHandle(String facetType) {
        if (facetType == null) {
            return false;
        }
        return facetType.equals(FacetTypes.W_DIFFERENCES) ||
            facetType.equals(FacetTypes.W_DIFFERENCES_FILTERED);
    }


    @Override
    public String getAxisLabel(DiagramGenerator generator) {
        return generator.msg(I18N_WDIFF_YAXIS_LABEL,
                I18N_WDIFF_YAXIS_LABEL_DEFAULT);
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
